@@ -1,10 +1,11 @@
 #!/usr/bin/env python
-from . import convert
-from .pdf import PDF
 import argparse
-from itertools import chain
 import json
 import sys
+from itertools import chain
+
+from . import convert
+from .pdf import PDF
 
 
 def parse_page_spec(p_str):
@@ -28,6 +29,8 @@ def parse_args(args_raw):
 
     parser.add_argument("--laparams", type=json.loads)
 
+    parser.add_argument("--precision", type=int)
+
     parser.add_argument("--pages", nargs="+", type=parse_page_spec)
 
     parser.add_argument(
@@ -43,7 +46,11 @@ def parse_args(args_raw):
 def main(args_raw=sys.argv[1:]):
     args = parse_args(args_raw)
     converter = {"csv": convert.to_csv, "json": convert.to_json}[args.format]
-    kwargs = {"csv": {}, "json": {"indent": args.indent}}[args.format]
+    kwargs = {
+        "csv": {"precision": args.precision},
+        "json": {"precision": args.precision, "indent": args.indent},
+    }[args.format]
+
     with PDF.open(args.infile, pages=args.pages, laparams=args.laparams) as pdf:
         converter(pdf, sys.stdout, args.types, **kwargs)
 
