@@ -38,15 +38,11 @@ def make_cluster_dict(values, tolerance):
         [(val, i) for val in value_cluster] for i, value_cluster in enumerate(clusters)
     ]
 
-    cluster_dict = dict(itertools.chain(*nested_tuples))
-    return cluster_dict
+    return dict(itertools.chain(*nested_tuples))
 
 
 def cluster_objects(objs, attr, tolerance):
-    if isinstance(attr, (str, int)):
-        attr_getter = itemgetter(attr)
-    else:
-        attr_getter = attr
+    attr_getter = itemgetter(attr) if isinstance(attr, (str, int)) else attr
     objs = to_list(objs)
     values = map(attr_getter, objs)
     cluster_dict = make_cluster_dict(values, tolerance)
@@ -59,9 +55,7 @@ def cluster_objects(objs, attr, tolerance):
 
     grouped = itertools.groupby(cluster_tuples, key=get_1)
 
-    clusters = [list(map(get_0, v)) for k, v in grouped]
-
-    return clusters
+    return [list(map(get_0, v)) for k, v in grouped]
 
 
 def decode_text(s):
@@ -71,9 +65,8 @@ def decode_text(s):
     """
     if type(s) == bytes and s.startswith(b"\xfe\xff"):
         return str(s[2:], "utf-16be", "ignore")
-    else:
-        ords = (ord(c) if type(c) == str else c for c in s)
-        return "".join(PDFDocEncoding[o] for o in ords)
+    ords = (ord(c) if type(c) == str else c for c in s)
+    return "".join(PDFDocEncoding[o] for o in ords)
 
 
 def resolve_and_decode(obj):
@@ -134,11 +127,8 @@ def resolve_all(x):
     elif t in (list, tuple):
         return t(resolve_all(v) for v in x)
     elif t == dict:
-        if get_dict_type(x) == "Annot":
-            exceptions = ["Parent"]
-        else:
-            exceptions = []
-        return dict((k, v if k in exceptions else resolve_all(v)) for k, v in x.items())
+        exceptions = ["Parent"] if get_dict_type(x) == "Annot" else []
+        return {k: v if k in exceptions else resolve_all(v) for k, v in x.items()}
     else:
         return x
 
@@ -451,7 +441,7 @@ collate_chars = extract_text
 
 def filter_objects(objs, fn):
     if isinstance(objs, dict):
-        return dict((k, filter_objects(v, fn)) for k, v in objs.items())
+        return {k: filter_objects(v, fn) for k, v in objs.items()}
 
     initial_type = type(objs)
     objs = to_list(objs)
@@ -494,10 +484,8 @@ def clip_obj(obj, bbox):
     for attr in ["x0", "top", "x1", "bottom"]:
         copy[attr] = dims[attr]
 
-    if dims["top"] != obj["bottom"] or dims["top"] != obj["bottom"]:
-        diff = dims["top"] - obj["top"]
-        copy["doctop"] = obj["doctop"] + diff
-
+    diff = dims["top"] - obj["top"]
+    copy["doctop"] = obj["doctop"] + diff
     copy["width"] = copy["x1"] - copy["x0"]
     copy["height"] = copy["bottom"] - copy["top"]
 
@@ -521,7 +509,7 @@ def within_bbox(objs, bbox):
     Filters objs to only those fully within the bbox
     """
     if isinstance(objs, dict):
-        return dict((k, within_bbox(v, bbox)) for k, v in objs.items())
+        return {k: within_bbox(v, bbox) for k, v in objs.items()}
 
     initial_type = type(objs)
     objs = to_list(objs)
@@ -539,7 +527,7 @@ def crop_to_bbox(objs, bbox):
     and crops the extent of the objects to the bbox.
     """
     if isinstance(objs, dict):
-        return dict((k, crop_to_bbox(v, bbox)) for k, v in objs.items())
+        return {k: crop_to_bbox(v, bbox) for k, v in objs.items()}
 
     initial_type = type(objs)
     objs = to_list(objs)
